==> dl.php?src=linea21_1_3_1.zip: linea21/languages/it/lang_common.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules pour menu
*  	*/
$lang['menu']['general'] = "Amministrazione generale";
$lang['menu']['theme'] = "Gestione dei temi";
$lang['menu']['scale'] = "Gestione delle scale";
$lang['menu']['level'] = "Gestione dei livelli";
$lang['menu']['user'] = "Gestione degli utenti";
$lang['menu']['news'] = "Gestione delle news";
$lang['menu']['newsletter'] = "Gestione delle newsletters";
$lang['menu']['yellowpages'] = "Gestione della rubrica";
$lang['menu']['workshop'] = "Gestione dei gruppi di lavoro";
$lang['menu']['publication'] = "Gestione delle pubblicazioni";	
$lang['menu']['sdi'] = "Gestione degli indicatori";
$lang['menu']['project'] = "Gestione dei progetti";
$lang['menu']['forum'] = "Gestione dei forum";
$lang['menu']['item'] = "Oggetti selezionati";
$lang['menu']['search'] = "Ricerca";
$lang['menu']['advancedsearch'] = "Ricerca avanzata";
$lang['menu']['dashboard'] = "Gestione del pannello di controllo";
$lang['menu']['system'] = "Configurazione";
$lang['menu']['tools'] = "Strumenti";

/*	nommage des modules
*  	*/
$lang['name']['news_module'] = "news";
$lang['name']['publication_module'] = "pubblicazione";
$lang['name']['det_publication_module'] = "sezione cartelle di pubblicazione";
$lang['name']['workshop_module'] = "gruppo di lavoro";
$lang['name']['workshoprep_module'] = "rapporto dei gruppi di lavoro";
$lang['name']['workshoprepcon_module'] = "sezione rapporto dei gruppi di lavoro";
$lang['name']['workshopcal_module'] = "calendario";
$lang['name']['workshopcom_module'] = "discussione";
$lang['name']['sdi_module'] = 'indicatore di sviluppo sostenibile';

/*	nommage datePicker
*  	*/
$lang['datePicker']['TEXT_PREV_YEAR']= "Anno precedente";
$lang['datePicker']['TEXT_PREV_MONTH']= "Mese precedente";
$lang['datePicker']['TEXT_NEXT_YEAR']= "Anno seguente";
$lang['datePicker']['TEXT_NEXT_MONTH']= "Mese seguente";
$lang['datePicker']['TEXT_CLOSE']= "Chiudi";
$lang['datePicker']['TEXT_CHOOSE_DATE']= "Scegli la data";

/*	nommage header
*  	*/
$lang['header']['title']= "Linea 21, il tuo spazio per l'amministrazione";
$lang['header']['welcome']= "Benvenuto";
$lang['header']['deconnexion']= "disconnetti";
$lang['header']['deconnexion_title']= "disconnettersi";
$lang['header']['myaccount']="Il mio account";
$lang['header']['myaccount_title']="autenticarsi e/o accedere al proprio account";
$lang['header']['goto_contents']="Andare ai contenuti";

/*	nommage chemin
*  	*/
$lang['way']['home']= "Home";
$lang['recap']['title']="Riepilogo delle informazioni inserite"; 

/*	action bouton
*  	*/
$lang['btn']['valid']= "convalida";
$lang['btn']['save']= "salva";
$lang['btn']['annul']= "annulla";
$lang['btn']['preview']= "modifica i parametri";

/*	statut

*  	*/
$lang['statut']['draft']='non pubblicato';
$lang['statut']['draftpdf']='non pubblico';
$lang['statut']['published_on']="pubblicato il";
$lang['statut']['archived_on']="archiviato il";
$lang['statut']['public']="Pubblico";
$lang['statut']['E']="Eliminato";
$lang['statut']['AA']="Amministratore di Archivio";
$lang['statut']['PA']="Archivio pubblico";
$lang['statut']['W']="in attesa - pianificato";
$lang['statut']['C']="Chiuso";
$lang['statut']['U']="Utente";
$lang['statut']['O']="Organizzatore";
$lang['statut']['A']="Amministratore";



/*	divers
*  	*/
$lang['divers']['yes']='sì';
$lang['divers']['no']='no';
$lang['divers']['nc']='n.c.';
$lang['divers']['none']='nessuno';
$lang['divers']['actions']='azioni';
$lang['divers']['no_comment']='nessun commento';
$lang['divers']['nodata']='nessun dato';
$lang['divers']['novisu']="nessuna immagine associata";
$lang['divers']['see_visual']='visualizza l\'immagine';
$lang['divers']['last_modify']="ultima modifica il";
$lang['divers']['date_crea']="data di creazione";
$lang['divers']['date_sup']="data di eliminazione";
$lang['divers']['date_publi']="data di pubblicatione";
$lang['divers']['sup_confirm']="Richiesta di conferma dell'eliminazione";
$lang['divers']['statut']="statuto";
$lang['divers']['range']="rango";
$lang['divers']['query_result']="Risultato della richiesta";
$lang['divers']['record']="registrazione";
$lang['divers']['records']="registrazioni";
$lang['divers']['version']="Linea 21, spazio d'amministratione : versione ".LINEA_VERSION ;
$lang['divers']['select_choice']="~~ Scegli nella lista qui sotto ~~";
$lang['divers']['select_choice2']="~~ scegli ~~";
$lang['divers']['enlarge_photo']='immagine ingrandita (dopo il click)';
$lang['divers']['by']="per";
$lang['divers']['goto_archives']='consultare gli archivi';
$lang['divers']['goto_currentlist']='ritorna alla lista principale';
$lang['divers']['page']='pagina';
$lang['divers']['seconds']='secondi';
$lang['divers']['back_public']='torna all\'interfaccia pubblica';
$lang['divers']['backpage']='Pagina precedente';
$lang['divers']['licence']='applicazione sotto licenza %s';
$lang['divers']['select_all']='seleziona tutto';
$lang['divers']['modify']='Modifica';
$lang['divers']['delete']='Elimina';
$lang['divers']['permalink']='permalink';
$lang['divers']['404']="Questa pagina non esiste!";

/* system
************************/
$lang['divers']['cookies']='Spiacenti, i cookies devono essere attivati per cambiare gli stili.';
$lang['divers']['redirect_string']='Sarete reindirizzati su %s in %d secondi.';
$lang['divers']['sql_connect_failed']='La connessione al server SQL è fallita';
$lang['divers']['db_connect_failed']='La connessione con il database è fallita';
$lang['divers']['sql_query_failed']='Fallimento della richiesta SQL';

/*	security
*  	*/
$lang['antispam']['info']="Anti-spam";
$lang['security']['info']="Per una maggior sicurezza, copia il codice a fianco";
$lang['security']['info2']="Copiare questo codice nel campo previsto a tale scopo";
$lang['security']['message']="Il codice di sicurezza inserito è errato! Attenzione, il codice tiene conto delle maiuscole e delle minuscole.";


/*	aide
*  	*/
$lang['help']['name']="Aiuto";
$lang['help']['title']="Bisogno d'aiuto ? clicca qui";
$lang['help']['img']="Bisogno d'aiuto ? clicca qui";
$lang['help']['contact']="Per qualsiasi domanda relativa all'amministrazione di linea21";
$lang['help']['support']="contatta il nostro supporto"; 

/*	interface publique
*  	*/
$lang['divers']['level']="Livello ";
$lang['divers']['scale']="Scala ";
$lang['divers']['themeref']="Tema ";

$lang['divers']['priority_choice']="Selezione per priorità ";
$lang['divers']['level_choice']="Selezione per livello ";
$lang['divers']['scale_choice']="Selezione per scala ";
$lang['divers']['themeref_choice']="Selezione per tema ";
$lang['divers']['actu_left']="News";
$lang['divers']['sdi_left']="Gli ultimi indicatori";
$lang['divers']['contact']="Contatti";
$lang['divers']['accessibility']="Accessibilità";
$lang['divers']['print']="Stampa questa pagina";

$lang['divers']['sousthemeref']="Sottotemi ";
$lang['divers']['trialpha']="Selezione per ordine alfabetico";
$lang['divers']['nodata']="nessun dato è attualmente disponibile";
$lang['divers']['newsletter_public_comment']= " L'abbonamento alla newsletter permette di ricevere le ultime novità e altre informazioni direttamente nella vostra casella di posta elettronica.";
$lang['newsletter']['unsubscribe']= 'Disiscriviti';


/*	check date
*  	*/
$lang['date']['not_valid'] = 'La data inserita non è corretta (format : '. DATE_FORMAT.')';
$lang['date']['date_do_not_exist'] = 'La data inserita non esiste.';

/*	authentification
*  	*/
$lang['divers']['auth']="autenticarsi";
$lang['divers']['noauth']="Non sei autenticato.";
$lang['divers']['creaauth']="Per autenticarsi o creare un account ";
$lang['divers']['errorauth']="Un problema è sorto durante l'autenticazione, per favore riconnettersi.";
$lang['divers']['user_inscription']="Iscriversi";
$lang['divers']['user_inscription_title']="creare il proprio account";
$lang['divers']['login']="Username";
$lang['divers']['password']="Password";
$lang['divers']['email']="email";
$lang['divers']['errorauth']="Username o password non validi";
$lang['divers']['errorauthadmin']="Non hai i diritti di amministratore su questo modulo";
/**
$lang['divers']['auth_mess1']="Connettersi come amministratore (gestione dell'intero sito) :<br />
- username : adminuser<br />
- password : adminuser<br />
<br />
Per connettersi come redattore (gestione delle pubblicazioni, novità e pannello di controllo) :<br />
- username : redattore<br />
- password : redattore<br /><br />";
*/
$lang['divers']['title_login']="Accedi allo spazio di amministrazione di Linea21";
$lang['divers']['auth_mess1']="Per accedere all'interfaccia di amministrazione devi attivare i cookies.";
$lang['divers']['auth_mess2']="Hai perso la tua password? Contatta l'amministratore qui : ";

$lang['public']['edito']="In una logica di trasparenza, Linea21 mette a disposizione un sistema di
publicazione e un programma di gestione degli indicatori di sviluppo sostenibile.
L'applicazione è indirizzata, nella parte dedicata ai clienti, alle collettività che utilizzano
agenda21 ed è destinata, in termini di comunicazione, a tutti i cittadini.
<br /><br />Linea21, uno strumento d'aiuto innovativo per la gestione e la messa in opera di agenda21.
<br />Per il candidato che è stato eletto : traduce le sue scelte politiche e strategiche in materia
d'ambiente e di sviluppo sostenibile nell'esercizio delle sue
funzioni.<br /><br />";

$lang['public']['workgroup_h1']="Gruppi di lavoro";
$lang['public']['workgroup_edito']="Essere coinvolti e partecipare. Ti invitiamo a partecipare e a integrare un gruppo di lavoro al fine di concentrare le riflessioni sulle problematiche dello sviluppo sostenibile.";
$lang['public']['dashboard_h1']="Pannello di controllo";
$lang['public']['last_news_h1']="Le nostre ultime pubblicazioni";
$lang['public']['dashboard_edito']="Dai un'occhiata agli ultimi valori degli indicatori di sviluppo sostenibile del tuo comune. Il nostro pannello di controllo degli indicatori è aggiornato regolarmente.";

$lang['check_update']['dl']='La versione %s é disponibile. Scarica qui';
$lang['check_update']['ok']='La versione attuale è la più recente';
$lang['check_update']['search']='Ricerca una nuova versione';
$lang['debug']['enabled']='è activato.';

/**
 * CSS Switcher
 */
$lang['css_switcher']['nostyle'] = 'nessuno stile';
$lang['css_switcher']['default'] = 'classico';
$lang['css_switcher']['minimal'] = 'minimo';
$lang['css_switcher']['darkstyle'] = 'bianco su nero';

/*	nommage des modules autre style blue_linea
*  	*/
$lang['menu_alt']['general'] = "Amministrazione generale";
$lang['menu_alt']['theme'] = "temi";
$lang['menu_alt']['scale'] = "scale";
$lang['menu_alt']['level'] = "livelli";
$lang['menu_alt']['user'] = "utenti";
$lang['menu_alt']['news'] = "news";
$lang['menu_alt']['newsletter'] = "newsletters";
$lang['menu_alt']['yellowpages'] = "rubrica";
$lang['menu_alt']['workshop'] = "gruppi di lavoro";
$lang['menu_alt']['publication'] = "pubblicazioni";	
$lang['menu_alt']['sdi'] = "indicatori";
$lang['menu_alt']['project'] = "progetti";
$lang['menu_alt']['forum'] = "forum";
$lang['menu_alt']['dashboard'] = "pannello di controllo";
$lang['menu_alt']['system'] = "sistema";
$lang['menu_alt']['tools'] = "strumenti";
$lang['menu_alt']['communication'] = "comunica";
$lang['menu_alt']['suivi_gestion'] = "segui &amp; gestisci";
$lang['menu_alt']['configuration'] = "configura";
$lang['menu_alt']['interface_publique'] = "vai sul sito web";
$lang['menu_alt']['search_here'] = "La tua ricerca...";
$lang['menu_alt']['valid_login'] = "Accedi a Linea21";
$lang['menu_alt']['all'] = "in tutto il sito";
?>

==> dl.php?src=linea21_1_4.zip: linea21/languages/it/lang_common.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules pour menu
 *  	*/
$lang['menu']['general'] = "Amministrazione generale";
$lang['menu']['theme'] = "Gestione dei temi";
$lang['menu']['scale'] = "Gestione delle scale";
$lang['menu']['level'] = "Gestione dei livelli";
$lang['menu']['user'] = "Gestione degli utenti";
$lang['menu']['news'] = "Gestione delle news";
$lang['menu']['newsletter'] = "Gestione delle newsletters";
$lang['menu']['yellowpages'] = "Gestione della rubrica";
$lang['menu']['workshop'] = "Gestione dei gruppi di lavoro";
$lang['menu']['publication'] = "Gestione delle pubblicazioni";
$lang['menu']['sdi'] = "Gestione degli indicatori";
$lang['menu']['project'] = "Gestione dei progetti";
$lang['menu']['forum'] = "Gestione dei forum";
$lang['menu']['item'] = "Oggetti selezionati";
$lang['menu']['search'] = "Ricerca";
$lang['menu']['advancedsearch'] = "Ricerca avanzata";
$lang['menu']['dashboard'] = "Gestione del pannello di controllo";
$lang['menu']['system'] = "Configurazione";
$lang['menu']['plugins'] = "Plugins";
$lang['menu']['library'] = "Mediateca";

/*	nommage des modules
 *  	*/
$lang['name']['news_module'] = "news";
$lang['name']['publication_module'] = "pubblicazione";
$lang['name']['det_publication_module'] = "sezione cartelle di pubblicazione";
$lang['name']['workshop_module'] = "gruppo di lavoro";
$lang['name']['workshoprep_module'] = "rapporto dei gruppi di lavoro";
$lang['name']['workshoprepcon_module'] = "sezione rapporto dei gruppi di lavoro";
$lang['name']['workshopcal_module'] = "calendario";
$lang['name']['workshopcom_module'] = "discussione";
$lang['name']['sdi_module'] = 'indicatore di sviluppo sostenibile';

/*	nommage datePicker
 *  	*/
$lang['datePicker']['TEXT_PREV_YEAR']= "Anno precedente";
$lang['datePicker']['TEXT_PREV_MONTH']= "Mese precedente";
$lang['datePicker']['TEXT_NEXT_YEAR']= "Anno seguente";
$lang['datePicker']['TEXT_NEXT_MONTH']= "Mese seguente";
$lang['datePicker']['TEXT_CLOSE']= "Chiudi";
$lang['datePicker']['TEXT_CHOOSE_DATE']= "Scegli la data";

/*	nommage header
 *  	*/
$lang['header']['title']= "Linea 21, il tuo spazio per l'amministrazione";
$lang['header']['welcome']= "Benvenuto";
$lang['header']['deconnexion']= "disconnetti";
$lang['header']['deconnexion_title']= "disconnettersi";
$lang['header']['myaccount']="Il mio account";
$lang['header']['myaccount_title']="autenticarsi e/o accedere al proprio account";
$lang['header']['goto_contents']="Andare ai contenuti";

/*	nommage chemin
 *  	*/
$lang['way']['home']= "Home";
$lang['recap']['title']="Riepilogo delle informazioni inserite";

/*	action bouton
 *  	*/
$lang['btn']['valid']= "convalida";
$lang['btn']['save']= "salva";
$lang['btn']['annul']= "annulla";
$lang['btn']['preview']= "modifica i parametri";

/*	statut

*  	*/
$lang['statut']['draft']='non pubblicato';
$lang['statut']['draftpdf']='non pubblico';
$lang['statut']['published_on']="pubblicato il";
$lang['statut']['archived_on']="archiviato il";
$lang['statut']['public']="Pubblico";
$lang['statut']['E']="Eliminato";
$lang['statut']['AA']="Amministratore di Archivio";
$lang['statut']['PA']="Archivio pubblico";
$lang['statut']['W']="in attesa - pianificato";
$lang['statut']['C']="Chiuso";
$lang['statut']['U']="Utente";
$lang['statut']['O']="Organizzatore";
$lang['statut']['A']="Amministratore";

/*	Contact
 *  	*/
$lang['contact']['name']= "Name"; // @todo translation
$lang['contact']['email']="Email"; // @todo translation
$lang['contact']['subject']= "Subject"; // @todo translation
$lang['contact']['body']="Body"; // @todo translation
$lang['contact']['email_error']="<em>%s</em> is not a valid email."; // @todo translation
$lang['contact']['str_error']= "Please fill-up the field <em>%s</em>."; // @todo translation
$lang['contact']['message_sent']="Your message has been sent with success."; // @todo translation
$lang['contact']['contact_us']="Contact us"; // @todo translation

/*	divers
 *  	*/
$lang['divers']['yes']='sì';
$lang['divers']['no']='no';
$lang['divers']['nc']='n.c.';
$lang['divers']['none']='nessuno';
$lang['divers']['actions']='azioni';
$lang['divers']['no_comment']='nessun commento';
$lang['divers']['comment']='commento';
$lang['divers']['optional']='facoltativo';
$lang['divers']['nodata']='nessun dato';
$lang['divers']['novisu']="nessuna immagine associata";
$lang['divers']['see_visual']='visualizza l\'immagine';
$lang['divers']['last_modify']="ultima modifica il";
$lang['divers']['date_crea']="data di creazione";
$lang['divers']['date_sup']="data di eliminazione";
$lang['divers']['date_publi']="data di pubblicatione";
$lang['divers']['sup_confirm']="Richiesta di conferma dell'eliminazione";
$lang['divers']['statut']="statuto";
$lang['divers']['range']="rango";
$lang['divers']['query_result']="Risultato della richiesta";
$lang['divers']['record']="registrazione";
$lang['divers']['records']="registrazioni";
$lang['divers']['version']="Linea 21, spazio d'amministratione : versione ".LINEA_VERSION ;
$lang['divers']['select_choice']="~~ Scegli nella lista qui sotto ~~";
$lang['divers']['select_choice2']="~~ scegli ~~";
$lang['divers']['enlarge_photo']='immagine ingrandita (dopo il click)';
$lang['divers']['by']="per";
$lang['divers']['goto_archives']='consultare gli archivi';
$lang['divers']['goto_currentlist']='ritorna alla lista principale';
$lang['divers']['page']='pagina';
$lang['divers']['seconds']='secondi';
$lang['divers']['back_public']='torna all\'interfaccia pubblica';
$lang['divers']['backpage']='Pagina precedente';
$lang['divers']['licence']='applicazione sotto licenza %s';
$lang['divers']['select_all']='seleziona tutto';
$lang['divers']['modify']='Modifica';
$lang['divers']['delete']='Elimina';
$lang['divers']['permalink']='permalink';
$lang['divers']['404']="Questa pagina non esiste!";
$lang['divers']['no_files']="no file"; // @todo translation
$lang['divers']['browse']="Browse ..."; // @todo translation
$lang['divers']['dl']="Download"; // @todo translation
$lang['divers']['up']="Upload"; // @todo translation
$lang['divers']['up_file']="Upload file"; // @todo translation
$lang['divers']['delqueue']="Delete queue"; // @todo translation
$lang['divers']['replace_file'] = "Do you want to replace the file"; // @todo translation
$lang['access']['workgroup']="Access to the group"; // @todo translation

/* system
 ************************/
$lang['divers']['cookies']='Spiacenti, i cookies devono essere attivati per cambiare gli stili.';
$lang['divers']['redirect_string']='Sarete reindirizzati su %s in %d secondi.';
$lang['divers']['sql_connect_failed']='La connessione al server SQL è fallita';
$lang['divers']['db_connect_failed']='La connessione con il database è fallita';
$lang['divers']['sql_query_failed']='Fallimento della richiesta SQL';
$lang['alert']['cookie_disabled']='Your browser does not accept cookies. Please enable cookies to log-in.'; // @todo translation

/*	security
 *  	*/
$lang['antispam']['info']="Anti-spam";
$lang['security']['info']="Per una maggior sicurezza, copia il codice a fianco";
$lang['security']['info2']="Copiare questo codice nel campo previsto a tale scopo";
$lang['security']['message']="Il codice di sicurezza inserito è errato! Attenzione, il codice tiene conto delle maiuscole e delle minuscole.";


/*	aide
 *  	*/
$lang['help']['name']="Aiuto";
$lang['help']['title']="Bisogno d'aiuto ? clicca qui";
$lang['help']['img']="Bisogno d'aiuto ? clicca qui";
$lang['help']['contact']="Per qualsiasi domanda relativa all'amministrazione di linea21";
$lang['help']['support']="contatta il nostro supporto";

/*	interface publique
 *  	*/
$lang['groups']['mine']="I miei gruppi";
$lang['groups']['his']="I suoi gruppi";
$lang['divers']['level']="Livello ";
$lang['divers']['scale']="Scala ";
$lang['divers']['themeref']="Tema ";

$lang['divers']['priority_choice']="Selezione per priorità ";
$lang['divers']['level_choice']="Selezione per livello ";
$lang['divers']['scale_choice']="Selezione per scala ";
$lang['divers']['themeref_choice']="Selezione per tema ";
$lang['divers']['actu_left']="News";
$lang['divers']['sdi_left']="Gli ultimi indicatori";
$lang['divers']['contact']="Contatti";
$lang['divers']['accessibility']="Accessibilità";
$lang['divers']['print']="Stampa questa pagina";

$lang['divers']['sousthemeref']="Sottotemi ";
$lang['divers']['trialpha']="Selezione per ordine alfabetico";
$lang['divers']['nodata']="nessun dato è attualmente disponibile";
$lang['divers']['newsletter_public_comment']= " L'abbonamento alla newsletter permette di ricevere le ultime novità e altre informazioni direttamente nella vostra casella di posta elettronica.";
$lang['newsletter']['unsubscribe']= 'Disiscriviti';
$lang['auth']['no_user']="<em>%s</em> is not known as a valid user"; // @todo translation
$lang['auth']['sending_mail']="An email has been sent to %s"; // @todo translation
$lang['auth']['note']="To receive a new password, please enter your login."; // @todo translation

/*	check date
 *  	*/
$lang['date']['not_valid'] = 'La data inserita non è corretta (format : '. DATE_FORMAT.')';
$lang['date']['date_do_not_exist'] = 'La data inserita non esiste.';

/*	authentification
 *  	*/
$lang['divers']['auth']="autenticarsi";
$lang['divers']['myprofile']="Mio account";
$lang['divers']['noauth']="Non sei autenticato.";
$lang['divers']['creaauth']="Per autenticarsi o creare un account ";
$lang['divers']['errorauth']="Un problema è sorto durante l'autenticazione, per favore riconnettersi.";
$lang['divers']['user_inscription']="Iscriversi";
$lang['divers']['user_inscription_title']="creare il proprio account";
$lang['divers']['login']="Username";
$lang['divers']['password']="Password";
$lang['divers']['email']="email";
$lang['divers']['errorauth']="Username o password non validi";
$lang['auth']['forgot_password']="Forgot your password?"; // @todo translation
$lang['divers']['errorauthadmin']="Non hai i diritti di amministratore su questo modulo";
/**
 $lang['divers']['auth_mess1']="Connettersi come amministratore (gestione dell'intero sito) :<br />
 - username : adminuser<br />
 - password : adminuser<br />
 <br />
 Per connettersi come redattore (gestione delle pubblicazioni, novità e pannello di controllo) :<br />
 - username : redattore<br />
 - password : redattore<br /><br />";
 */
$lang['divers']['title_login']="Accedi allo spazio di amministrazione di Linea21";
$lang['divers']['auth_mess1']="Per accedere all'interfaccia di amministrazione devi attivare i cookies.";
$lang['divers']['auth_mess2']="Hai perso la tua password? Contatta l'amministratore qui : ";

$lang['public']['edito']="In una logica di trasparenza, Linea21 mette a disposizione un sistema di
publicazione e un programma di gestione degli indicatori di sviluppo sostenibile.
L'applicazione è indirizzata, nella parte dedicata ai clienti, alle collettività che utilizzano
agenda21 ed è destinata, in termini di comunicazione, a tutti i cittadini.
<br /><br />Linea21, uno strumento d'aiuto innovativo per la gestione e la messa in opera di agenda21.
<br />Per il candidato che è stato eletto : traduce le sue scelte politiche e strategiche in materia
d'ambiente e di sviluppo sostenibile nell'esercizio delle sue
funzioni.<br /><br />";

$lang['public']['workgroup_h1']="Gruppi di lavoro";
$lang['public']['workgroup_edito']="Essere coinvolti e partecipare. Ti invitiamo a partecipare e a integrare un gruppo di lavoro al fine di concentrare le riflessioni sulle problematiche dello sviluppo sostenibile.";
$lang['public']['dashboard_h1']="Pannello di controllo";
$lang['public']['last_news_h1']="Le nostre ultime pubblicazioni";
$lang['public']['dashboard_edito']="Dai un'occhiata agli ultimi valori degli indicatori di sviluppo sostenibile del tuo comune. Il nostro pannello di controllo degli indicatori è aggiornato regolarmente.";

$lang['check_update']['dl']='La versione %s é disponibile. Scarica qui';
$lang['check_update']['ok']='La versione attuale è la più recente';
$lang['check_update']['search']='Ricerca una nuova versione';

/**
 * CSS Switcher
 */
$lang['css_switcher']['nostyle'] = 'nessuno stile';
$lang['css_switcher']['default'] = 'classico';
$lang['css_switcher']['minimal'] = 'minimo';
$lang['css_switcher']['darkstyle'] = 'bianco su nero';

/*	nommage des modules autre style blue_linea
 *  	*/
$lang['menu_alt']['general'] = "Amministrazione generale";
$lang['menu_alt']['theme'] = "temi";
$lang['menu_alt']['scale'] = "scale";
$lang['menu_alt']['level'] = "livelli";
$lang['menu_alt']['user'] = "utenti";
$lang['menu_alt']['news'] = "news";
$lang['menu_alt']['newsletter'] = "newsletters";
$lang['menu_alt']['yellowpages'] = "rubrica";
$lang['menu_alt']['workshop'] = "gruppi di lavoro";
$lang['menu_alt']['publication'] = "pubblicazioni";
$lang['menu_alt']['sdi'] = "indicatori";
$lang['menu_alt']['project'] = "progetti";
$lang['menu_alt']['forum'] = "forum";
$lang['menu_alt']['dashboard'] = "pannello di controllo";
$lang['menu_alt']['system'] = "sistema";
$lang['menu_alt']['plugins'] = "plugins";
$lang['menu_alt']['library'] = "mediateca";
$lang['menu_alt']['communication'] = "comunica";
$lang['menu_alt']['suivi_gestion'] = "segui &amp; gestisci";
$lang['menu_alt']['configuration'] = "configura";
$lang['menu_alt']['interface_publique'] = "vai sul sito web";
$lang['menu_alt']['search_here'] = "La tua ricerca...";
$lang['menu_alt']['valid_login'] = "Accedi a Linea21";
$lang['menu_alt']['all'] = "in tutto il sito";
$lang['menu_alt']['home'] = "in tutto il sito";

?>
